@@ -35,8 +35,8 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         super(MyMainForm, self).__init__(parent)
         self.setupUi(self)
 
-        current_path = os.path.realpath(__file__)
-        app_icon = QIcon( "qtt.png")
+        current_path = os.path.dirname(__file__)
+        app_icon = QIcon(current_path+ "/qtt.png")
         self.setWindowIcon(app_icon)
 
         self.btnOpen.clicked.connect(self.select_file)
@@ -855,8 +855,9 @@ class WorkThread(QThread):
 def main():
     app = QApplication(sys.argv)
 
-    current_path = os.path.realpath(__file__)
-    app_icon = QIcon("qtt.png")
+    current_path = os.path.dirname(__file__)
+    print("current path = ",current_path)
+    app_icon = QIcon(current_path+"/qtt.png")
     app.setWindowIcon(app_icon)
 
     myWin = MyMainForm()
