@@ -30,7 +30,8 @@ def gui_topic_prevalence(
         num_words=50,
         num_pass=10,
         stopwords_path="",
-        result_path=""
+        result_path="",
+        prefix_filename=""
 ):
 
 
@@ -61,11 +62,12 @@ def gui_topic_prevalence(
         tag_field=category_field,
         time_field=time_field,
         id_field=id_field,
-        prefix_filename="",
+        prefix_filename=prefix_filename,
         lang=lang,
         num_topics=num_topics,
         num_words=num_words,
-        num_pass=num_pass
+        num_pass=num_pass,
+
     )
 
     # print('result: ',list_tp_topics)
