@@ -1,11 +1,12 @@
 from gensim import  models
 from quick_topic.topic_interaction.lda_by_tag_each import *
 from quickcsv.file import *
-
+import pickle
 def build_lda_model(list_doc,num_topics=6,num_words=50,num_pass=5,list_term_file=None,stopwords_path="",save_name="topic",output_folder="output",lang='zh',
                     random_state=100,
                     chunk_size=10,
-                    iteration=100
+                    iteration=100,
+                    list_useful_words=None
                     ):
 
     # ============ begin configure ====================
@@ -36,7 +37,7 @@ def build_lda_model(list_doc,num_topics=6,num_words=50,num_pass=5,list_term_file
     if lang == 'zh':
         for pp in list_term_file:
             jieba.load_userdict(pp)
-        texts = get_text_chinese(list_doc, stopwords_path=stopwords_path)
+        texts = get_text_chinese(list_doc, stopwords_path=stopwords_path,list_useful_words=list_useful_words)
     else:
         texts = get_text_english(list_doc)
 
@@ -46,6 +47,8 @@ def build_lda_model(list_doc,num_topics=6,num_words=50,num_pass=5,list_term_file
     # convert tokenized documents into a document-term matrix
     corpus = [dictionary.doc2bow(text) for text in texts]
 
+    ldamodel=None
+
     # generate LDA model
     if lang == 'en':
         ldamodel = gensim.models.ldamodel.LdaModel(corpus,
@@ -72,6 +75,14 @@ def build_lda_model(list_doc,num_topics=6,num_words=50,num_pass=5,list_term_file
                                                    per_word_topics=True
                                                    )
 
+    model_folder = output_folder + "/model"
+    if not os.path.exists(model_folder):
+        os.mkdir(model_folder)
+
+    ldamodel.save(model_folder + "/ldamodel.model")
+
+    pickle.dump(texts, open(model_folder + "/texts.pickle", "wb"))
+
     ## list_topic_weights=get_topic_weights(ldamodel=ldamodel,corpus=corpus)
 
     # print keywords
@@ -106,7 +117,6 @@ def get_topic_distribution(lda_model,corpus):
     dominant_topic_in_each_doc = df.groupby('Dominant_Topic').size()
     df_dominant_topic_in_each_doc = dominant_topic_in_each_doc.to_frame(name='count').reset_index()
 
-
     # df_dominant_topic_in_each_doc.to_csv(output_folder + "/" + save_dominant_topic_file, encoding='utf-8')
 
     # Total Topic Distribution by actual weight
@@ -166,7 +176,8 @@ def build_lda_models(meta_csv_file,raw_text_folder,tag_field="area",id_field="fi
                      prefix_filename="text_",list_term_file=None,stopwords_path="",
                      output_folder="results/topic_modeling",
                     num_topics=6,num_words=50,num_pass=5,
-                     lang='zh'
+                     lang='zh',
+                     min_doc_num=10
                      ):
 
     #meta_csv_file = "datasets/list_country.csv"
@@ -192,6 +203,8 @@ def build_lda_models(meta_csv_file,raw_text_folder,tag_field="area",id_field="fi
             dict_country[area] = [text]
 
     for country in dict_country:
+        if len(dict_country[country])<min_doc_num:
+            continue
         if not os.path.exists(output_folder):
             os.mkdir(output_folder)
         build_lda_model(
