@@ -542,9 +542,6 @@ def show_topic_distribution(df_dominant_topic_in_each_doc,df_topic_weightage_by_
 def show_tsne(lda_model,corpus,num_topics=4,output_folder=""):
     # Get topic weights and dominant topics ------------
     from sklearn.manifold import TSNE
-    from bokeh.plotting import figure, output_file, show
-    from bokeh.models import Label
-    from bokeh.io import output_notebook
 
     from bokeh.plotting import figure, output_file, save
     output_file(filename=output_folder+"/tsne.html", title="Static HTML file")
